@@ -157,6 +157,14 @@ class IGithubRepo(metaclass=abstracts.Interface):
         """Iterate commits for this repo."""
         raise NotImplementedError
 
+    @abstracts.interfacemethod
+    async def create_release(
+            self,
+            branch: str,
+            name: str) -> Dict[str, str | Dict]:
+        """Create a release for this repo."""
+        raise NotImplementedError
+
     @abstracts.interfacemethod
     async def highest_release(
             self,
@@ -188,6 +196,11 @@ class IGithubRepo(metaclass=abstracts.Interface):
         """Fetch a tag for this repo."""
         raise NotImplementedError
 
+    @abstracts.interfacemethod
+    async def tag_exists(self, tag_name: str) -> str:
+        """Check whether a tag already exists."""
+        raise NotImplementedError
+
 
 class IGithubIssue(metaclass=abstracts.Interface):
 
